stacker_blueprints
==================

An attempt at a common Blueprint library for use with `stacker <https://github.com/remind101/stacker>`_.

If you're new to stacker you may use `stacker_cookiecutter <https://github.com/remind101/stacker_cookiecutter>`_ to setup your project.
